import { makeStyles,Typography } from '@material-ui/core'
import { useState } from 'react';
import { styled } from '@mui/material/styles';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';
import VolumeOffIcon from '@mui/icons-material/VolumeOff';
import ListItemButton from '@mui/material/ListItemButton';
import Avatar from '@mui/material/Avatar';
import ListItemText from '@mui/material/ListItemText';
import ListItemIcon from '@mui/material/ListItemIcon';
import DoneAllIcon from '@mui/icons-material/DoneAll';
import PushPinIcon from '@mui/icons-material/PushPin';

import { TChat } from '../../../../../../typescript/redux/chats/types';
import { firstLetter,slicedWord,timeStampEU } from '../../../../../../helpers';

const StyledMenu = styled((props:any) => (
  <Menu
    elevation={0}
    anchorOrigin={{
      vertical: 'top',
      horizontal: 'right',
    }}
    transformOrigin={{
      vertical: 'bottom',
      horizontal: 'right',
    }}
    {...props}
  />
))(({ theme }:any) => ({
  '& .MuiPaper-root': {
    borderRadius: 10,
    marginTop: theme.spacing(0),
    minWidth: 220,
    color:
      theme.palette.mode === 'light' ? 'rgb(55, 65, 81)' : theme.palette.grey[500],
    boxShadow:
      'rgb(255, 255, 255) 0px 0px 0px 0px, rgba(0, 0, 0, 0.05) 0px 0px 0px 1px, rgba(0, 0, 0, 0.1) 0px 10px 15px -3px, rgba(0, 0, 0, 0.05) 0px 4px 6px -2px',
    '& .MuiMenu-list': {
      padding: '8px 8px',
    },
    '& .MuiMenuItem-root': {
      marginBottom: theme.spacing(1),
      '& .MuiSvgIcon-root': {
        fontSize: 21,
        color: theme.palette.text.secondary,
        marginRight: theme.spacing(4),
      }
    },
  },
}));

const useStyles = makeStyles({
  listItemInnerText: {
    display: 'flex',
    alignContent: 'center',
    alignItems: 'center',
    flexWrap: 'nowrap',
  },
  listItem_iconAvatar: {
    marginRight:10
  },
  listItem_iconRight: {
    marginRight: 10,
  },
  listItem_icon_time: {
    fontSize: 12,
    marginLeft: 5,
    paddingBottom:25,
    color: '#1b1b1b'
  },
})

interface IChatItem {
  chat: TChat,
  handleListItemClick: (companionId: string) => void,
}

const  ChatItem = ({chat,handleListItemClick}:IChatItem) => {
  const classes = useStyles()
  const [anchorEl, setAnchorEl] = useState<any>(null);
  const [selected, setSelected] = useState<boolean>(false);
  const open = Boolean(anchorEl);
  const {name,lastName,avatarUrl,color,companionId,lastMessage,lastMessageCreatedAt,createdAt} = chat

  const handleClose = (type: string | undefined): void => {
    if (type === 'pin') console.log('pin to top')
    setAnchorEl(null)
    setSelected(false)
  }
  const handleContextMenu = (e: React.MouseEvent<HTMLDivElement>):void => {
    e.preventDefault()
    setAnchorEl(e.currentTarget)
    setSelected(true)
  }  

  return (
    <div>
      <ListItemButton
        selected={selected}
        onClick={() => handleListItemClick(companionId)}
        onContextMenu={(e) => handleContextMenu(e)}
      >
        <ListItemIcon className={classes.listItem_iconAvatar}>
          <Avatar alt={name} src={avatarUrl?`http://localhost:3000/${avatarUrl}`:undefined}
            sx={{ background: color, width: 54, height: 54 }}>
            {!avatarUrl&&`${firstLetter(name)}${firstLetter(lastName)}`}
          </Avatar>
        </ListItemIcon> 
        <ListItemText primary={`${firstLetter(name)}${slicedWord(name, 15, 1)} 
            ${firstLetter(lastName)}${slicedWord(lastName, 15, 1)}`}
            secondary={`${lastMessage ? slicedWord(lastMessage, 35) :
            `${firstLetter(name)}${slicedWord(name, 8, 1)} joined Telegram`}`}/>
        <ListItemIcon className={classes.listItem_iconRight}>
          <Typography className={classes.listItem_icon_time} variant="h6" color="initial">
            {timeStampEU(lastMessageCreatedAt?lastMessageCreatedAt:createdAt)}
          </Typography>
        </ListItemIcon>            
      </ListItemButton>
      <StyledMenu
        id="demo-positioned-menu"
        aria-labelledby="demo-positioned-button"
        anchorEl={anchorEl}
        open={open}
        onClose={handleClose}
      >
         <MenuItem onClick={() => handleClose('pin')}>
            <PushPinIcon /> 
            Pin to top
          </MenuItem>      
       </StyledMenu>    
    </div>
  );
}
export default ChatItem