import { makeStyles } from '@material-ui/core'
import List from '@mui/material/List';
import Stack from '@mui/material/Stack';
import { useSelector,useDispatch } from 'react-redux';
import { getStateMemo } from '../../../../../redux/chats/selector';
import { getIsOpen } from '../../../../../redux/control/selector';
import { sortByRecent } from '../../../../../helpers';
import { asyncStartChatById } from '../../../../../redux/chat/operations';
import { actionIsOpen } from '../../../../../redux/control/action';
import RecentItem from './RecentItem';
import ChatItem from './ChatItem';
import AlertInfo from '../../../../reusableComponents/AlertInfo';

const useStyles = makeStyles({
  stack: {
    display: 'flex',
    justifyContent: 'space-around',
    paddingTop:20,
  },
  list: {
    width: '100%',
    maxHeight: '890px',
    overflowY: 'scroll',
  '&::-webkit-scrollbar': {
    width: '0.4em'
  },
  '&::-webkit-scrollbar-track': {
    boxShadow: 'inset 0 0 6px rgba(0,0,0,0.00)',
    webkitBoxShadow: 'inset 0 0 6px rgba(0,0,0,0.00)',
    backgroundColor: '#eceeec',
  },
  '&::-webkit-scrollbar-thumb': {
    backgroundColor: '#ccc8c8',
    },
  "&::-webkit-scrollbar-thumb:focus": {
    backgroundColor: "#959595",
          },
  "&::-webkit-scrollbar-thumb:active": {
    backgroundColor: "#959595",
    },
  },    
})

const ChatListRecent = ({value}:{value: string}) => {
  const classes = useStyles()
  const dispatch = useDispatch()
  const { chats } = useSelector(getStateMemo)
  const isOpen = useSelector(getIsOpen)
  const handleListItemClick = (companionId: string) => {
    isOpen&&dispatch(actionIsOpen(''))
    dispatch(asyncStartChatById(companionId))
    }
  const filteredAndSortedChats = () => sortByRecent(chats).filter((el) => {
    const credentials = el.name + ' ' + el.lastName
    if(credentials.toLowerCase().includes(value.toLowerCase())) return el
  })
  const arr = filteredAndSortedChats()

return (
  <>
    {!value && arr.length > 0 &&
    <Stack direction="row" className={classes.stack}>
      {arr.slice(0, 6).map((chat) =>
      <RecentItem key={chat.companionId} handleListItemClick={handleListItemClick} chat={chat} />)}
      </Stack>}
    {value && arr.length > 0 &&
      <List className={classes.list} component="nav" aria-label="main mailbox folders">
        {arr.map((chat) =>
        <ChatItem key={chat.companionId} handleListItemClick={handleListItemClick} chat={chat} />)}
      </List>}
    {value && arr.length === 0 &&<AlertInfo name={`Can not find chat by request: ${value}`}/>}
  </>)  
}

export default ChatListRecent